==> takeaction-0.1.tgz: takeaction/tests/test_takeaction.py <==
# takeaction: content as actions
# Copyright (C) 2007 Plone Solutions AS
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
import unittest
from Products.CMFPlone.interfaces.Translatable import ITranslatable

class DummyResult:
    _View_Permission = None
        
    def __init__(self, id):
        self._id = id
        
    def Title(self):
        return 'Title of %s' % self._id
    
    def Description(self):
        return 'Description of %s' % self._id
    
    def absolute_url(self):
        return 'Path of %s' % self._id
    
class TranslatableDummyResult(DummyResult):
    __implements__ = (ITranslatable,)
    
    def getTranslation(self):
        return DummyResult(self._id + ' translation')
    
class DummyPortal:
    def __init__(self, paths=None):
        self._paths = paths
        
    def getPortalObject(self):
        return self
    
    def unrestrictedTraverse(self, path, default):
        id = self._paths.get(path)
        if id is not None:
            if path.endswith('/translation'):
                return TranslatableDummyResult(id)
            res = DummyResult(id)
            if path.endswith('/protected'):
                res._View_Permission = ()
            return res
        return default

class TakeActionTests(unittest.TestCase):
    def setUp(self):
        from Products.takeaction.takeaction import TakeActionTool
        self.tool = TakeActionTool()
        self.tool.portal_url = DummyPortal({
            '/foo/bar': 'baz',
            '/spam/eggs': 'monty',
            '/foo/translation': 'python',
            '/foo/protected': 'perl'
        })
        
    def testEmpty(self):
        self.assertEqual(self.tool.listActions(), [])
        
    def testNonExistent(self):
        self.tool.content_paths = ('/no/such/path',)
        self.assertEqual(self.tool.listActions(), [])
        
    def testNoAccess(self):
        self.tool.content_paths = ('/foo/protected',)
        self.assertEqual(self.tool.listActions(), [])
        
    def testCategory(self):
        self.tool.category = 'foobar'
        self.tool.content_paths = ('/foo/bar',)
        result = self.tool.listActions()
        self.assertEqual(result[0].getCategory(), 'foobar')
        
    def testNonTranslatable(self):
        self.tool.content_paths = ('/foo/bar', '/spam/eggs')
        result = self.tool.listActions()
        self.assertEqual(len(result), 2)
        self.assertEqual(result[0].getId(), 'takeaction00')
        self.assertEqual(result[0].Title(), 'Title of baz')
        self.assertEqual(result[0].Description(), 'Description of baz')
        self.assertEqual(result[0].getActionExpression(), 'string:Path of baz')
        self.assertEqual(result[1].Title(), 'Title of monty')
        
    def testTranslatable(self):
        self.tool.content_paths = ('/foo/translation',)
        result = self.tool.listActions()
        self.assertEqual(result[0].Title(), 'Title of python translation')

def test_suite():
    suite = unittest.TestSuite()
    suite.addTests((
        unittest.makeSuite(TakeActionTests),
    ))
    return suite

if __name__ == '__main__':
    unittest.main()

==> takeaction-0.3.tgz: takeaction/tests/test_takeaction.py <==
# takeaction: content as actions
# Copyright (C) 2007 Plone Solutions AS
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
import unittest
from Products.CMFPlone.interfaces.Translatable import ITranslatable

class DummyResult:
    _View_Permission = None
        
    def __init__(self, id):
        self._id = id
        
    def getId(self):
        return self._id
        
    def Title(self):
        return 'Title of %s' % self._id
    
    def Description(self):
        return 'Description of %s' % self._id
    
    def absolute_url(self):
        return 'Path of %s' % self._id
    
class TranslatableDummyResult(DummyResult):
    __implements__ = (ITranslatable,)
    
    def getTranslation(self, language=None):
        if self._id == 'no-translation':
            return None
        if self._id == 'language-neutral':
            if language is None:
                return None
            return DummyResult(self._id + ' language neutral')
        return DummyResult(self._id + ' translation')
    
class DummyPortal:
    def __init__(self, paths=None):
        self._paths = paths
        
    def getPortalObject(self):
        return self
    
    def unrestrictedTraverse(self, path, default):
        id = self._paths.get(path)
        if id is not None:
            if path.endswith('/translation'):
                return TranslatableDummyResult(id)
            res = DummyResult(id)
            if path.endswith('/protected'):
                res._View_Permission = ()
            return res
        return default

class TakeActionTests(unittest.TestCase):
    def setUp(self):
        from Products.takeaction.takeaction import TakeActionTool
        self.tool = TakeActionTool()
        self.tool.portal_url = DummyPortal({
            '/foo/bar': 'baz',
            '/foo/spam/bar': 'baz',
            '/foo/eggs/bar': 'baz',
            '/spam/eggs': 'monty',
            '/foo/translation': 'python',
            '/foo/protected': 'perl',
            '/bar/translation': 'no-translation',
            '/baz/translation': 'language-neutral'
        })
        
    def testEmpty(self):
        """No paths in the tool means no actions"""
        self.assertEqual(self.tool.listActions(), [])
        
    def testNonExistent(self):
        """Non-existing paths result in no actions"""
        self.tool.content_paths = ('/no/such/path',)
        self.assertEqual(self.tool.listActions(), [])
        
    def testNoAccess(self):
        """No view access means no actions"""
        self.tool.content_paths = ('/foo/protected',)
        self.assertEqual(self.tool.listActions(), [])
        
    def testCategory(self):
        """Setting the action category results in actions with that category"""
        self.tool.category = 'foobar'
        self.tool.content_paths = ('/foo/bar',)
        result = self.tool.listActions()
        self.assertEqual(result[0].getCategory(), 'foobar')
        
    def testNonTranslatable(self):
        """Normal CMF content paths results"""
        self.tool.content_paths = ('/foo/bar', '/spam/eggs')
        result = self.tool.listActions()
        self.assertEqual(len(result), 2)
        self.assertEqual(result[0].getId(), 'takeaction-baz')
        self.assertEqual(result[0].Title(), 'Title of baz')
        self.assertEqual(result[0].Description(), 'Description of baz')
        self.assertEqual(result[0].getActionExpression(), 'string:Path of baz')
        self.assertEqual(result[1].getId(), 'takeaction-monty')
        self.assertEqual(result[1].Title(), 'Title of monty')
        
    def testDuplicateIds(self):
        """Unique action ids even when there are duplicate object ids"""
        self.tool.content_paths = ('/foo/bar', '/foo/spam/bar', '/foo/eggs/bar')
        result = self.tool.listActions()
        self.assertEqual(len(result), 3)
        self.assertEqual(result[0].getId(), 'takeaction-baz')
        self.assertEqual(result[1].getId(), 'takeaction-baz-2')
        self.assertEqual(result[2].getId(), 'takeaction-baz-3')
        
    def testTranslatable(self):
        """Translatable content results in actions for tranlations"""
        self.tool.content_paths = ('/foo/translation',)
        result = self.tool.listActions()
        self.assertEqual(result[0].getId(), 'takeaction-python')
        self.assertEqual(result[0].Title(), 'Title of python translation')
        
    def testTranslatableNoTranslation(self):
        """Translatable without an appropriate translation means no action"""
        self.tool.content_paths = ('/bar/translation',)
        self.assertEqual(self.tool.listActions(), [])
        
    def testTranslatableLanguageNeutral(self):
        """Translatable, no translation, but with language neutral version"""
        self.tool.content_paths = ('/baz/translation',)
        result = self.tool.listActions()
        self.assertEqual(result[0].getId(), 'takeaction-language-neutral')
        self.assertEqual(result[0].Title(),
                         'Title of language-neutral language neutral')

def test_suite():
    suite = unittest.TestSuite()
    suite.addTests((
        unittest.makeSuite(TakeActionTests),
    ))
    return suite

if __name__ == '__main__':
    unittest.main()
